`listFile` examples

These examples show how `listFile` should work on the birds and fish lists provided with the starter code.

    In []:listFile('birds.txt')
    Prints1 tern
    2 albatross
    3 seagull
    4 sparrow
    5 cardinal
    6 oriole
    7 robin
    8 swallow
    9 stork
    10 cassowary
    11 ostrich
    12 chicken
    13 tanager
    14 goose
    15 turkey
    16 quail
    17 chickadee
    18 nuthatch

    In []:listFile('fish.txt')
    Prints1 tuna
    2 swordfish
    3 sawfish
    4 sunfish
    5 mackerel
    6 anchovy
    7 flying fish
    8 angler fish
    9 lantern fish
    10 salmon
    11 carp
    12 catfish